@@ -16,7 +16,7 @@ def test_datetime_serialization(todo_factory, tmpdir):
     todo = todo_factory(created_at=now)
     filename = tmpdir.join("default").join(todo.filename)
     with open(str(filename)) as f:
-        assert "CREATED;VALUE=DATE-TIME:20170831T234953Z\n" in f.readlines()
+        assert "CREATED:20170831T234953Z\n" in f.readlines()
 
 
 def test_serialize_created_at(todo_factory):
@@ -39,7 +39,7 @@ def test_serializer_raises(todo_factory):
     todo = todo_factory()
     writter = VtodoWriter(todo)
 
-    with pytest.raises(Exception):
+    with pytest.raises(Exception, match="Unknown field nonexistant"):
         writter.serialize_field("nonexistant", 7)
 
 
