@@ -1,5 +1,6 @@
 import json
 from datetime import datetime
+from uuid import uuid4
 
 import pytz
 
@@ -14,6 +15,7 @@ def test_list_all(tmpdir, runner, create):
         "STATUS:COMPLETED\n"
         "COMPLETED:20181225T191234Z\n"
         "DUE;VALUE=DATE-TIME;TZID=CET:20160102T000000\n"
+        "DTSTART:20160101T000000Z\n"
         "PERCENT-COMPLETE:26\n"
         "LOCATION:Wherever\n",
     )
@@ -21,6 +23,7 @@ def test_list_all(tmpdir, runner, create):
 
     expected = [
         {
+            "categories": [],
             "completed": True,
             "completed_at": 1545765154,
             "description": "",
@@ -30,6 +33,39 @@ def test_list_all(tmpdir, runner, create):
             "location": "Wherever",
             "percent": 26,
             "priority": 0,
+            "start": 1451606400,
+            "summary": "Do stuff",
+        }
+    ]
+
+    assert not result.exception
+    assert result.output.strip() == json.dumps(expected, indent=4, sort_keys=True)
+
+
+def test_list_start_date(tmpdir, runner, create):
+    create(
+        "test.ics",
+        "SUMMARY:Do stuff\n"
+        "STATUS:COMPLETED\n"
+        "DTSTART;VALUE=DATE:20160102\n"
+        "PERCENT-COMPLETE:26\n"
+        "LOCATION:Wherever\n",
+    )
+    result = runner.invoke(cli, ["--porcelain", "list", "--status", "ANY"])
+
+    expected = [
+        {
+            "categories": [],
+            "completed": True,
+            "completed_at": None,
+            "description": "",
+            "due": None,
+            "id": 1,
+            "list": "default",
+            "location": "Wherever",
+            "percent": 26,
+            "priority": 0,
+            "start": 1451692800,
             "summary": "Do stuff",
         }
     ]
@@ -51,6 +87,7 @@ def test_list_due_date(tmpdir, runner, create):
 
     expected = [
         {
+            "categories": [],
             "completed": True,
             "completed_at": None,
             "description": "",
@@ -60,6 +97,7 @@ def test_list_due_date(tmpdir, runner, create):
             "location": "Wherever",
             "percent": 26,
             "priority": 0,
+            "start": None,
             "summary": "Do stuff",
         }
     ]
@@ -69,11 +107,15 @@ def test_list_due_date(tmpdir, runner, create):
 
 
 def test_list_nodue(tmpdir, runner, create):
-    create("test.ics", "SUMMARY:Do stuff\nPERCENT-COMPLETE:12\nPRIORITY:4\n")
+    create(
+        "test.ics",
+        f"UID:{uuid4()}\nSUMMARY:Do stuff\nPERCENT-COMPLETE:12\nPRIORITY:4\n",
+    )
     result = runner.invoke(cli, ["--porcelain", "list"])
 
     expected = [
         {
+            "categories": [],
             "completed": False,
             "completed_at": None,
             "description": "",
@@ -83,6 +125,7 @@ def test_list_nodue(tmpdir, runner, create):
             "location": "",
             "percent": 12,
             "priority": 4,
+            "start": None,
             "summary": "Do stuff",
         }
     ]
@@ -95,10 +138,10 @@ def test_list_priority(tmpdir, runner, create):
     result = runner.invoke(cli, ["--porcelain", "list"], catch_exceptions=False)
     assert not result.exception
     assert result.output.strip() == "[]"
-    create("one.ics", "SUMMARY:haha\nPRIORITY:4\n")
-    create("two.ics", "SUMMARY:hoho\nPRIORITY:9\n")
-    create("three.ics", "SUMMARY:hehe\nPRIORITY:5\n")
-    create("four.ics", "SUMMARY:huhu\n")
+    create("one.ics", f"UID:{uuid4()}\nSUMMARY:haha\nPRIORITY:4\n")
+    create("two.ics", f"UID:{uuid4()}\nSUMMARY:hoho\nPRIORITY:9\n")
+    create("three.ics", f"UID:{uuid4()}\nSUMMARY:hehe\nPRIORITY:5\n")
+    create("four.ics", f"UID:{uuid4()}\nSUMMARY:huhu\n")
 
     result_high = runner.invoke(cli, ["--porcelain", "list", "--priority=4"])
     assert not result_high.exception
@@ -133,10 +176,15 @@ def test_list_priority(tmpdir, runner, create):
 
 
 def test_show(tmpdir, runner, create):
-    create("test.ics", "SUMMARY:harhar\nDESCRIPTION:Lots of text. Yum!\nPRIORITY:5\n")
+    create(
+        "test.ics",
+        f"UID:{uuid4()}\nSUMMARY:harhar\n"
+        "DESCRIPTION:Lots of text. Yum!\nPRIORITY:5\n",
+    )
     result = runner.invoke(cli, ["--porcelain", "show", "1"])
 
     expected = {
+        "categories": [],
         "completed": False,
         "completed_at": None,
         "description": "Lots of text. Yum!",
@@ -146,6 +194,7 @@ def test_show(tmpdir, runner, create):
         "location": "",
         "percent": 0,
         "priority": 5,
+        "start": None,
         "summary": "harhar",
     }
 
@@ -158,6 +207,7 @@ def test_simple_action(todo_factory):
     todo = todo_factory(id=7, location="Downtown")
 
     expected = {
+        "categories": [],
         "completed": False,
         "completed_at": None,
         "description": "",
@@ -167,6 +217,7 @@ def test_simple_action(todo_factory):
         "location": "Downtown",
         "percent": 0,
         "priority": 0,
+        "start": None,
         "summary": "YARR!",
     }
 
